@@ -35,11 +35,11 @@
 #include <fcntl.h>
 
 #ifdef UNIX_DOMAIN_SOCKETS
-static int connect_to_unix_server __P((void));
+static int connect_to_unix_server (void);
 #endif
 
 #ifdef INTERNET_DOMAIN_SOCKETS
-static int connect_to_internet_server __P((const char *, u_short));
+static int connect_to_internet_server (const char *serverhost, u_short port);
 #endif
 
 /* On some systems, e.g. DGUX, inet_addr returns a 'struct in_addr'. */
@@ -247,7 +247,8 @@ connect_to_internet_server (const char *serverhost, u_short port)
 	peeraddr_in.sin_family = AF_INET;
 
 	/* look up the server host's internet address */
-	if (((long) peeraddr_in.sin_addr.s_addr = glibtop_internet_addr (serverhost)) == -1)
+	peeraddr_in.sin_addr.s_addr = glibtop_internet_addr (serverhost);
+	if ((long) peeraddr_in.sin_addr.s_addr == -1)
 		glibtop_error ("unable to find %s in /etc/hosts or from YP", serverhost);
 
 	if (port == 0) {
